[![Build Status](https://travis-ci.com/jkrasting/cmip_basins.svg?branch=main)](https://travis-ci.com/jkrasting/cmip_basins) [![Total alerts](https://img.shields.io/lgtm/alerts/g/jkrasting/cmip_basins.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/jkrasting/cmip_basins/alerts/) [![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/jkrasting/cmip_basins.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/jkrasting/cmip_basins/context:python)
